@@ -8,7 +8,7 @@ die "Usage: perl support.pl <what_to_lookup>\n"
 
 my $What = shift;
 
-use lib '../lib';
+use lib qw(../lib lib);
 use WWW::WebDevout::BrowserSupportInfo;
 
 my $wd = WWW::WebDevout::BrowserSupportInfo->new( long => 1 );
@@ -19,7 +19,8 @@ $wd->fetch( $What )
 print "Support for " . $wd->what;
 
 my $results = $wd->browser_results;
-printf "\n\t%-20s: %s", $_, $results->{ $_ }
+
+printf "\n\t%-20s: %s", $_, $results->{ $_ } || 'N/A'
     for sort keys %$results;
 
 printf "\nYou can find more information on %s\n", $wd->uri_info;
